@@ -594,7 +594,7 @@ handle_system_report (http_connection_t *connection, const char *method,
   response_data = cmd_response_data_new ();
 
   /* Connect to manager */
-  switch (manager_connect (credentials, &con, response_data))
+  switch (manager_connect (credentials, &con))
     {
     case 0: /* success */
       res = get_system_report_gmp_from_url (
@@ -753,12 +753,64 @@ handle_static_config (http_connection_t *connection, const char *method,
                                   NULL);
 }
 
+static http_handler_t *
+make_url_handlers ()
+{
+  http_handler_t *url_handlers;
+  http_handler_t *gmp_handler, *gmp_url_handler;
+  http_handler_t *system_report_handler, *system_report_url_handler;
+  http_handler_t *logout_handler, *logout_url_handler;
+
+  url_handlers = url_handler_new ("^/(img|js|css|locales)/.+$",
+                                  http_handler_new (handle_static_file));
+
+  // Add simpler handlers.
+
+  url_handler_add_func (url_handlers, "^/robots\\.txt$", handle_static_file);
+
+  url_handler_add_func (url_handlers, "^/config\\.*js$", handle_static_config);
+  url_handler_add_func (url_handlers, "^/static/(img|js|css|media)/.+$",
+                        handle_static_file);
+  url_handler_add_func (url_handlers, "^/manual/.+$", handle_static_file);
+
+  // Create /gmp handler.
+
+  gmp_handler = http_handler_new (handle_setup_user);
+  http_handler_add (gmp_handler, http_handler_new (handle_setup_credentials));
+  http_handler_add (gmp_handler, http_handler_new (handle_gmp_get));
+  gmp_url_handler = url_handler_new ("^/gmp$", gmp_handler);
+
+  // Create /system_report handler.
+
+  system_report_handler = http_handler_new (handle_setup_user);
+  http_handler_add (system_report_handler,
+                    http_handler_new (handle_setup_credentials));
+  http_handler_add (system_report_handler,
+                    http_handler_new (handle_system_report));
+  system_report_url_handler =
+    url_handler_new ("^/system_report/.+$", system_report_handler);
+
+  // Create /logout handler.
+
+  logout_handler = http_handler_new (handle_get_user);
+  http_handler_add (logout_handler, http_handler_new (handle_logout));
+  logout_url_handler = url_handler_new ("^/logout/?$", logout_handler);
+
+  // Add the handlers.
+
+  http_handler_add (url_handlers, gmp_url_handler);
+  http_handler_add (url_handlers, system_report_url_handler);
+  http_handler_add (url_handlers, logout_url_handler);
+
+  http_handler_add (url_handlers, http_handler_new (handle_index));
+
+  return url_handlers;
+}
+
 http_handler_t *
 init_http_handlers ()
 {
-  http_handler_t *method_router;
-  http_handler_t *gmp_post_handler;
-  http_handler_t *url_handlers;
+  http_handler_t *method_router, *gmp_post_handler, *url_handlers;
 
   http_validator = gvm_validator_new ();
   gvm_validator_add (http_validator, "slave_id", SLAVE_ID_REGEXP);
@@ -771,38 +823,7 @@ init_http_handlers ()
 
   http_handler_add (handlers, method_router);
 
-  url_handlers = url_handler_new ("^/(img|js|css|locales)/.+$",
-                                  http_handler_new (handle_static_file));
-  url_handler_add_func (url_handlers, "^/robots\\.txt$", handle_static_file);
-
-  url_handler_add_func (url_handlers, "^/config\\.*js$", handle_static_config);
-  url_handler_add_func (url_handlers, "^/static/(img|js|css|media)/.+$",
-                        handle_static_file);
-  url_handler_add_func (url_handlers, "^/manual/.+$", handle_static_file);
-
-  http_handler_t *gmp_handler = http_handler_new (handle_setup_user);
-  http_handler_add (gmp_handler, http_handler_new (handle_setup_credentials));
-  http_handler_add (gmp_handler, http_handler_new (handle_gmp_get));
-  http_handler_t *gmp_url_handler = url_handler_new ("^/gmp$", gmp_handler);
-
-  http_handler_t *system_report_handler = http_handler_new (handle_setup_user);
-  http_handler_add (system_report_handler,
-                    http_handler_new (handle_setup_credentials));
-  http_handler_add (system_report_handler,
-                    http_handler_new (handle_system_report));
-  http_handler_t *system_report_url_handler =
-    url_handler_new ("^/system_report/.+$", system_report_handler);
-
-  http_handler_t *logout_handler = http_handler_new (handle_get_user);
-  http_handler_add (logout_handler, http_handler_new (handle_logout));
-  http_handler_t *logout_url_handler =
-    url_handler_new ("^/logout/?$", logout_handler);
-
-  http_handler_add (url_handlers, gmp_url_handler);
-  http_handler_add (url_handlers, system_report_url_handler);
-  http_handler_add (url_handlers, logout_url_handler);
-
-  http_handler_add (url_handlers, http_handler_new (handle_index));
+  url_handlers = make_url_handlers ();
 
   method_router_set_get_handler (method_router, url_handlers);
   method_router_set_post_handler (method_router, gmp_post_handler);
